==> Paws-0.1.tar.gz: Paws-0.1/lib/Paws/CloudFront/CreateDistributionResult.pm <==

package Paws::CloudFront::CreateDistributionResult {
  use Moose;
  has Distribution => (is => 'ro', isa => 'Paws::CloudFront::Distribution');
  has ETag => (is => 'ro', isa => 'Str');
  has Location => (is => 'ro', isa => 'Str');

}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudFront:: - Arguments for method  on Paws::CloudFront

=head1 DESCRIPTION

This class represents the parameters used for calling the method  on the 
Amazon CloudFront service. Use the attributes of this class
as arguments to method .

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to .

As an example:

  $service_obj->(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 Distribution => Paws::CloudFront::Distribution

  

The distribution's information.










=head2 ETag => Str

  

The current version of the distribution created.










=head2 Location => Str

  

The fully qualified URI of the new distribution resource just created.
For example:
https://cloudfront.amazonaws.com/2010-11-01/distribution/EDFDVBD632BHDS5.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method  in L<Paws::CloudFront>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.02.tar.gz: Paws-0.02/lib/Paws/CloudFront/CreateDistributionResult.pm <==

package Paws::CloudFront::CreateDistributionResult {
  use Moose;
  with 'Paws::API::ResultParser';
  has Distribution => (is => 'ro', isa => 'Paws::CloudFront::Distribution');
  has ETag => (is => 'ro', isa => 'Str');
  has Location => (is => 'ro', isa => 'Str');

}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudFront:: - Arguments for method  on Paws::CloudFront

=head1 DESCRIPTION

This class represents the parameters used for calling the method  on the 
Amazon CloudFront service. Use the attributes of this class
as arguments to method .

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to .

As an example:

  $service_obj->(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 Distribution => Paws::CloudFront::Distribution

  

The distribution's information.










=head2 ETag => Str

  

The current version of the distribution created.










=head2 Location => Str

  

The fully qualified URI of the new distribution resource just created.
For example:
https://cloudfront.amazonaws.com/2010-11-01/distribution/EDFDVBD632BHDS5.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for  in Paws::CloudFront

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
